import { useState } from 'react'
import '../css/global.css'
import BlackButton from './components/customButton'
import Animation from './components/animation.jsx';
import PlayVideo from './components/playVideo.jsx';
import LoadingScene from './components/loadingScene.jsx';

function IntroductionData({onClickedIntroduction}){

    return(
        <div 
            onClick={onClickedIntroduction}
            style={{
                position: "fixed",
                top: 0,
                left: 0,
                width: "100vw",
                height: "100vh",
                background: "rgba(var(--black), 0.5)",
                display: 'flex',
                justifyContent: 'center',
                alignItems: 'center',
                zIndex: 1 // Ensure this is above other elements
            }}
        >
            <label style={{color:"rgb(var(--white))", fontWeight:"bold"}}>
                You are a new student who just <br />
                transfered to this school not long ago. <br />
                You don't know anyone yet, <br />
                but eventually you  meet...
            </label>
        </div>
  )
}

function SelectionCharacter(){
    const [numChar, setNumChar] = useState(1);

    const handleLeftClicked = () => {
        var temp = numChar - 1
        if (temp<1){
            setNumChar(3)
        }
        else{
            setNumChar(temp)
        }
    };
    const handleRightClicked = () => {
        var temp = numChar + 1
        if (temp>3){
            setNumChar(1)
        }
        else{
            setNumChar(temp)
        }
    };

    class Character {
        name(num) {
            if (num === 1) {
                return "Porsche";
            } else if (num === 2) {
                return "Pie";
            } else if (num === 3) {
                return "Patt";
            } else {
                return "Invalid";
            }
        }
        position(num) {
            if (num === 1) {
                return "left";
            } else if (num === 2) {
                return "middle";
            } else if (num === 3) {
                return "right";
            } else {
                return "Invalid";
            }
        }
    }
    
    const character = new Character();;

    return (
        <div style={{
            position: "fixed",
            display: 'flex',
            justifyContent: 'center',
            alignItems: 'center',
            width: "100vw",
            height: "100vh",
            zIndex: 1,
        }}>
            <div className="button left" 
                onClick={handleLeftClicked}
                style={{
                    // background: 'white',
                    width:'10vw',
                    height:'20vh'
                }}
            >
                <img src="https://placehold.co/400x600" style={{width:'100%',height:'100%'}}/>
            </div>
            <div className="textBox" 
                style={{
                    display: 'flex',
                    justifyContent: 'center',
                    alignItems: 'center',
                    width:'10vw',
                    height:'20vh'
                }}>
                {character.name(numChar)}
            </div>
            <div className="button right" 
                onClick={handleRightClicked}
                style={{
                    // background: 'white',
                    width:'10vw',
                    height:'20vh'
                }}
            >
                <img src="https://placehold.co/400x600" style={{width:'100%',height:'100%'}}/>
            </div>
        </div>
    )
}

function IntroductionPage() {
    const [loading, setLoading] = useState(true);
    const [positionState, setPositionState] = useState("middle");
    const [isClickedIntroduction, setIsClickedIntroduction] = useState(false);


    const handleClickIntroduction = () => {
        setIsClickedIntroduction(true); 
        console.log(isClickedIntroduction)
    };

    const handleVideoReady = () => {
        setLoading(false); 
    };

    return (
        <div style={{
            width: "100vw",
            height: "100vh",
        }}>
            {loading ? (
                <LoadingScene />
            ) : (
                !isClickedIntroduction ? (
                    <IntroductionData onClickedIntroduction={handleClickIntroduction} />
                ) : (
                    <SelectionCharacter />
                )
            )}
            
            <PlayVideo src='hallway_FFF.mp4' side='middle' onVideoReady={handleVideoReady} />
        </div>
    );
}



export default IntroductionPage
